Documentation
¶
Index ¶
- Constants
- func All[T matter.Detectable]() *matter.Detector[T]
- func CollapseSecretString(s string) (string, error)
- func Detect[T matter.Detectable](filters ...expression.QueryFieldPredicate) *matter.Detector[T]
- func Fld(name string) matter.EntityField
- func Ignite(cmdSource *cobra.Command, source ...string)
- func IgniteBase(cmdSource *cobra.Command, source ...string)
- func IsSecretSourceFormat(s string) bool
- func MustHaveObserverClient() *mongo.Client
- func Record[C matter.Collapsible](ctx context.Context, obj C) error
- func SummonObservationFor(purpose matter.PurposeAffinity) *matter.MongoDataverse
- func SummonSecretManager() ether.SecretManager
- type BaseModel
- func (e *BaseModel) Collapse() matter.Ripple
- func (e *BaseModel) CollapseID() bson.ObjectID
- func (e *BaseModel) Decohere(ripple matter.Ripple) error
- func (e BaseModel) GetID() bson.ObjectID
- func (e BaseModel) HasID() bool
- func (e BaseModel) LastObserved() time.Time
- func (e BaseModel) SelfScope() expression.Scope
Constants ¶
const ( ModelState_Unset int32 = iota ModelState_Transition ModelState_Material )
Variables ¶
This section is empty.
Functions ¶
func CollapseSecretString ¶ added in v1.0.0
func Detect ¶ added in v1.3.0
func Detect[T matter.Detectable](filters ...expression.QueryFieldPredicate) *matter.Detector[T]
func Fld ¶ added in v0.5.4
func Fld(name string) matter.EntityField
func Ignite ¶ added in v1.0.0
Ignite the kosmos. A chain of events that materialize into existence an environment. Failure to do so will be fatal to the application. An application cannot exist without the kosmos.
func IgniteBase ¶ added in v1.0.3
Ignite Base the kosmos where Secret Manager is optional and no Observer Client is created. Failure to do so will be fatal to the application. An application cannot exist without the kosmos.
func IsSecretSourceFormat ¶ added in v1.0.2
func MustHaveObserverClient ¶ added in v0.8.4
func SummonObservationFor ¶ added in v0.7.3
func SummonObservationFor(purpose matter.PurposeAffinity) *matter.MongoDataverse
func SummonSecretManager ¶ added in v0.2.9
func SummonSecretManager() ether.SecretManager
Types ¶
type BaseModel ¶ added in v0.4.2
type BaseModel struct {
ID bson.ObjectID `xml:"id,attr" json:"ID" bson:"_id,omitempty"`
UpdatedTime time.Time `xml:"updated" json:"updated" bson:"updated_time"`
CreatedTime *time.Time `xml:"created" json:"created" bson:"created_time,omitempty"`
// contains filtered or unexported fields
}
Usage Embed BaseModel to your model struct as the first field with a kosmos tag Example: kosmos.BaseModel `bson:",inline" kosmos:"pieriansea>page"`
func (*BaseModel) CollapseID ¶ added in v0.4.2
func (BaseModel) LastObserved ¶ added in v0.4.11
func (BaseModel) SelfScope ¶ added in v1.2.4
func (e BaseModel) SelfScope() expression.Scope
Click to show internal directories.
Click to hide internal directories.